@@ -80,18 +80,24 @@ class WhereCondition:
 
     def __and__(self, other):
         self._and = other
-        return self
+        return self.clone()
 
     def __or__(self, other):
         self._or = other
-        return self
+        return self.clone()
 
     def __invert__(self):
         self._negated = not self._negated
-        return self
+        return self.clone()
 
     @classmethod
     def resolve_lookup(cls, lookup_key):
+        """
+        Takes a lookup string (like `foo__bar__lt`) and returns 2-tuple with lookup parts
+        split by last part ('foo__bar', 'lt').
+
+        Is used to separate field name (with relations if it's provided) and lookup part itself.
+        """
         *rest, lookup = lookup_key.split(LOOKUP_SEPARATOR)
 
         lookups = dict(cls.LOOKUP_MAPPING)
@@ -116,6 +122,16 @@ class WhereCondition:
 
         return cls(field=field_name, op=op, value=value)
 
+    # pylint: disable=protected-access
+    def clone(self):
+        new_where = self.__class__(field=self.field, op=self.op, value=self.value, no_escape=self.no_escape)
+        if self._and:
+            new_where._and = self._and.clone()
+        if self._or:
+            new_where._or = self._or.clone()
+        new_where._negated = self._negated
+        return new_where
+
 
 class OrderByExpression(namedtuple('OrderByExpression', 'value, ordering')):
     ASC = 'ASC'
